@@ -83,6 +83,7 @@ dt_options_tbl <-
     "heading_title_font_weight",          TRUE,  "heading",          "value",   "initial",
     "heading_subtitle_font_size",         TRUE,  "heading",          "px",      "85%",
     "heading_subtitle_font_weight",       TRUE,  "heading",          "value",   "initial",
+    "heading_padding",                    TRUE,  "heading",          "px",      "4px",
     "heading_border_bottom_style",        TRUE,  "heading",          "value",   "solid",
     "heading_border_bottom_width",        TRUE,  "heading",          "px",      "2px",
     "heading_border_bottom_color",        TRUE,  "heading",          "value",   "#D3D3D3",
@@ -93,6 +94,7 @@ dt_options_tbl <-
     "column_labels_font_size",            TRUE,  "column_labels",    "px",      "100%",
     "column_labels_font_weight",          TRUE,  "column_labels",    "value",   "normal",
     "column_labels_text_transform",       TRUE,  "column_labels",    "value",   "inherit",
+    "column_labels_padding",              TRUE,  "column_labels",    "px",      "5px",
     "column_labels_vlines_style",         TRUE,  "table_body",       "value",   "none",
     "column_labels_vlines_width",         TRUE,  "table_body",       "px",      "1px",
     "column_labels_vlines_color",         TRUE,  "table_body",       "value",   "#D3D3D3",
