@@ -21,8 +21,10 @@ dt_stub_df_init <- function(data,
   stub_df <-
     dplyr::tibble(
       rownum_i = seq_len(nrow(data_tbl)),
-      groupname = rep(NA_character_, nrow(data_tbl)),
-      rowname = rep(NA_character_, nrow(data_tbl))
+      group_id = rep(NA_character_, nrow(data_tbl)),
+      rowname = rep(NA_character_, nrow(data_tbl)),
+      group_label = rep(list(NULL), nrow(data_tbl)),
+      built = rep(NA_character_, nrow(data_tbl))
     )
 
   # If `rowname` is a column available in `data`,
@@ -38,23 +40,24 @@ dt_stub_df_init <- function(data,
 
   # If `data` is a `grouped_df` then create groups from the
   # group columns; note that this will overwrite any values
-  # already in `stub_df$groupname`
+  # already in `stub_df$group_id`
   if (!is.null(groupname_col) &&
       length(groupname_col) > 0 &&
       all(groupname_col %in% colnames(data_tbl))) {
 
-    row_group_labels <-
+    row_group_ids <-
       apply(
         data_tbl[, groupname_col],
         MARGIN = 1,
-        paste, collapse = row_group.sep
+        FUN = paste,
+        collapse = row_group.sep
       )
 
-    # Place the `group_labels` values into `stub_df$groupname`
-    stub_df[["groupname"]] <- row_group_labels
+    # Place the `group_labels` values into `stub_df$group_id`
+    stub_df[["group_id"]] <- row_group_ids
+    stub_df[["group_label"]] <- row_group_ids
 
     data <- data %>% dt_boxhead_set_row_group(vars = groupname_col)
-
   }
 
   # Stop if input `data` has no columns (after modifying
@@ -76,6 +79,29 @@ dt_stub_df_exists <- function(data) {
   available
 }
 
+dt_stub_df_build <- function(data, context) {
+
+  stub_df <- dt_stub_df_get(data = data)
+
+  stub_df$built <-
+    vapply(
+      stub_df$group_label,
+      FUN.VALUE = character(1),
+      FUN = function(label) {
+
+        if (!is.null(label)) {
+          process_text(label, context)
+        } else {
+          ""
+        }
+      }
+    )
+
+  data <- dt_stub_df_set(data = data, stub_df = stub_df)
+
+  data
+}
+
 # Function to obtain a reordered version of `stub_df`
 reorder_stub_df <- function(data) {
 
@@ -98,7 +124,7 @@ dt_stub_groupname_has_na <- function(data) {
 
   stub_df <- dt_stub_df_get(data = data)
 
-  any(is.na(stub_df$groupname))
+  any(is.na(stub_df$group_id))
 }
 
 dt_stub_components <- function(data) {
@@ -111,8 +137,8 @@ dt_stub_components <- function(data) {
     stub_components <- c(stub_components, "rowname")
   }
 
-  if (any(!is.na(stub_df[["groupname"]]))) {
-    stub_components <- c(stub_components, "groupname")
+  if (any(!is.na(stub_df[["group_id"]]))) {
+    stub_components <- c(stub_components, "group_id")
   }
 
   stub_components
@@ -127,19 +153,19 @@ dt_stub_components_is_rowname <- function(stub_components) {
 }
 
 # Function that checks `stub_components` and determines whether just the
-# `groupname` part is available; TRUE indicates that we are working with a table
+# `group_id` part is available; TRUE indicates that we are working with a table
 # with groups but it doesn't have rownames
 dt_stub_components_is_groupname <- function(stub_components) {
 
-  identical(stub_components, "groupname")
+  identical(stub_components, "group_id")
 }
 
 # Function that checks `stub_components` and determines whether the
-# `rowname` and `groupname` parts are available; TRUE indicates that we are
+# `rowname` and `group_id` parts are available; TRUE indicates that we are
 # working with a table with rownames and groups
 dt_stub_components_is_rowname_groupname <- function(stub_components) {
 
-  identical(stub_components, c("rowname", "groupname"))
+  identical(stub_components, c("rowname", "group_id"))
 }
 
 dt_stub_components_has_rowname <- function(stub_components) {
