@@ -87,6 +87,11 @@
 #'   of `1,000`).
 #' @param dec_mark The character to use as a decimal mark (e.g., using `dec_mark
 #'   = ","` with `0.152` would result in a formatted value of `0,152`).
+#' @param force_sign Should the positive sign be shown for positive values
+#'   (effectively showing a sign for all values except zero)? If so, use `TRUE`
+#'   for this option. The default is `FALSE`, where only negative numbers will
+#'   display a minus sign. This option is disregarded when using accounting
+#'   notation with `accounting = TRUE`.
 #' @param locale An optional locale ID that can be used for formatting the value
 #'   according the locale's rules. Examples include `"en_US"` for English
 #'   (United States) and `"fr_FR"` for French (France). The use of a valid
@@ -157,6 +162,7 @@ fmt_number <- function(data,
                        pattern = "{x}",
                        sep_mark = ",",
                        dec_mark = ".",
+                       force_sign = FALSE,
                        locale = NULL) {
 
   # Perform input object validation
@@ -175,9 +181,18 @@ fmt_number <- function(data,
 
   # Stop function if any columns have data that is incompatible
   # with this formatter
-  if (!column_classes_are_valid(data, {{ columns }}, valid_classes = c("numeric", "integer"))) {
-    stop("The `fmt_number()` function can only be used on `columns` with numeric data",
-         call. = FALSE)
+  if (
+    !column_classes_are_valid(
+      data = data,
+      columns = {{ columns }},
+      valid_classes = c("numeric", "integer")
+    )
+  ) {
+    stop(
+      "The `fmt_number()` and `fmt_integer()` functions can only be ",
+      "used on `columns` with numeric data",
+      call. = FALSE
+    )
   }
 
   # Set the `formatC_format` option according to whether number
@@ -203,36 +218,154 @@ fmt_number <- function(data,
       format_fn = function(x, context) {
 
         # Create the `suffix_df` object
-        suffix_df <- create_suffix_df(x, decimals, suffix_labels, scale_by)
+        suffix_df <-
+          create_suffix_df(
+            x,
+            decimals = decimals,
+            suffix_labels = suffix_labels,
+            scale_by = scale_by
+          )
 
+        # Scale the `x` values by the `scale_by` values in `suffix_df`
+        x <- scale_x_values(x, scale_by = suffix_df$scale_by)
+
+        # Format numeric values to character-based numbers
         x_str <-
-          x %>%
-          # Scale the `x_vals` by the `scale_by` values
-          scale_x_values(suffix_df$scale_by) %>%
-          # Format numeric values to character-based numbers
           format_num_to_str(
-            context = context, decimals = decimals, n_sigfig = n_sigfig,
-            sep_mark = sep_mark, dec_mark = dec_mark,
+            x,
+            context = context,
+            decimals = decimals,
+            n_sigfig = n_sigfig,
+            sep_mark = sep_mark,
+            dec_mark = dec_mark,
             drop_trailing_zeros = drop_trailing_zeros,
             drop_trailing_dec_mark = drop_trailing_dec_mark,
             format = formatC_format
-          ) %>%
-          # With large-number suffixing support, we paste the
-          # vector of suffixes to the right of the values
-          paste_right(suffix_df$suffix)
-
-        x_str <-
-          x_str %>%
-          format_as_accounting(
-            x = x, context = context, accounting = accounting
           )
 
+        # Paste the vector of suffixes to the right of the values
+        x_str <- paste_right(x_str, x_right = suffix_df$suffix)
+
+        # Format values in accounting notation (if `accounting = TRUE`)
+        x_str <-
+          format_as_accounting(
+            x_str,
+            x = x,
+            context = context,
+            accounting = accounting
+          )
+
+        # Force a positive sign on certain values if the option is taken
+        if (!accounting && force_sign) {
+
+          positive_x <- !is.na(x) & x > 0
+          x_str[positive_x] <- paste_left(x_str[positive_x], x_left = "+")
+        }
+
         x_str
       }
     )
   )
 }
 
+#' Format values as integers
+#'
+#' @description
+#' With numeric values in a **gt** table, we can perform number-based
+#' formatting so that the targeted values are always rendered as integer values.
+#' We can have fine control over integer formatting with the following options:
+#'
+#' - digit grouping separators: options to enable/disable digit separators
+#' and provide a choice of separator symbol
+#' - scaling: we can choose to scale targeted values by a multiplier value
+#' - large-number suffixing: larger figures (thousands, millions, etc.) can
+#' be autoscaled and decorated with the appropriate suffixes
+#' - pattern: option to use a text pattern for decoration of the formatted
+#' values
+#' - locale-based formatting: providing a locale ID will result in number
+#' formatting specific to the chosen locale
+#'
+#' @details
+#' Targeting of values is done through `columns` and additionally by `rows` (if
+#' nothing is provided for `rows` then entire columns are selected). Conditional
+#' formatting is possible by providing a conditional expression to the `rows`
+#' argument. See the Arguments section for more information on this.
+#'
+#' @inheritParams fmt_number
+#' @param suffixing An option to scale and apply suffixes to larger numbers
+#'   (e.g., `1924000` can be transformed to `2M`). This option can accept a
+#'   logical value, where `FALSE` (the default) will not perform this
+#'   transformation and `TRUE` will apply thousands (`K`), millions (`M`),
+#'   billions (`B`), and trillions (`T`) suffixes after automatic value scaling.
+#'   We can also specify which symbols to use for each of the value ranges by
+#'   using a character vector of the preferred symbols to replace the defaults
+#'   (e.g., `c("k", "Ml", "Bn", "Tr")`).
+#'
+#'   Including `NA` values in the vector will ensure that the particular range
+#'   will either not be included in the transformation (e.g, `c(NA, "M", "B",
+#'   "T")` won't modify numbers in the thousands range) or the range will
+#'   inherit a previous suffix (e.g., with `c("K", "M", NA, "T")`, all numbers
+#'   in the range of millions and billions will be in terms of millions).
+#'
+#'   Any use of `suffixing` (where it is not set expressly as `FALSE`) means
+#'   that any value provided to `scale_by` will be ignored.
+#'
+#' @return An object of class `gt_tbl`.
+#'
+#' @examples
+#' # Use `exibble` to create a gt table;
+#' # format the `num` column as integer
+#' # values having no digit separators
+#' tab_1 <-
+#'   exibble %>%
+#'   dplyr::select(num, char) %>%
+#'   gt() %>%
+#'   fmt_integer(
+#'     columns = num,
+#'     use_seps = FALSE
+#'   )
+#'
+#' @section Figures:
+#' \if{html}{\figure{man_fmt_integer_1.png}{options: width=100\%}}
+#'
+#' @family Format Data
+#' @section Function ID:
+#' 3-2
+#'
+#' @import rlang
+#' @export
+fmt_integer <- function(data,
+                        columns,
+                        rows = everything(),
+                        use_seps = TRUE,
+                        accounting = FALSE,
+                        scale_by = 1.0,
+                        suffixing = FALSE,
+                        pattern = "{x}",
+                        sep_mark = ",",
+                        force_sign = FALSE,
+                        locale = NULL) {
+
+  fmt_number(
+    data = data,
+    columns = {{ columns }},
+    rows = {{ rows }},
+    decimals = 0,
+    n_sigfig = NULL,
+    drop_trailing_zeros = FALSE,
+    drop_trailing_dec_mark = TRUE,
+    use_seps = use_seps,
+    accounting = accounting,
+    scale_by = scale_by,
+    suffixing = suffixing,
+    pattern = pattern,
+    sep_mark = sep_mark,
+    dec_mark = "not used",
+    force_sign = force_sign,
+    locale = locale
+  )
+}
+
 #' Format values to scientific notation
 #'
 #' @description
@@ -257,6 +390,10 @@ fmt_number <- function(data,
 #' @inheritParams fmt_number
 #' @param scale_by A value to scale the input. The default is `1.0`. All numeric
 #'   values will be multiplied by this value first before undergoing formatting.
+#' @param force_sign Should the positive sign be shown for positive values
+#'   (effectively showing a sign for all values except zero)? If so, use `TRUE`
+#'   for this option. The default is `FALSE`, where only negative numbers will
+#'   display a minus sign.
 #'
 #' @return An object of class `gt_tbl`.
 #'
@@ -286,7 +423,7 @@ fmt_number <- function(data,
 #'
 #' @family Format Data
 #' @section Function ID:
-#' 3-2
+#' 3-3
 #'
 #' @import rlang
 #' @export
@@ -299,6 +436,7 @@ fmt_scientific <- function(data,
                            pattern = "{x}",
                            sep_mark = ",",
                            dec_mark = ".",
+                           force_sign = FALSE,
                            locale = NULL) {
 
   # Perform input object validation
@@ -313,7 +451,7 @@ fmt_scientific <- function(data,
   dec_mark <- get_locale_dec_mark(locale, dec_mark)
 
   # Stop function if `locale` does not have a valid value
-  validate_locale(locale)
+  validate_locale(locale = locale)
 
   # Normalize the `suffixing` input to either return a character vector
   # of suffix labels, or NULL (the case where `suffixing` is FALSE)
@@ -321,9 +459,17 @@ fmt_scientific <- function(data,
 
   # Stop function if any columns have data that is incompatible
   # with this formatter
-  if (!column_classes_are_valid(data, {{ columns }}, valid_classes = c("numeric", "integer"))) {
-    stop("The `fmt_scientific()` function can only be used on `columns` with numeric data",
-         call. = FALSE)
+  if (
+    !column_classes_are_valid(
+      data = data,
+      columns = {{ columns }},
+      valid_classes = c("numeric", "integer")
+    )
+  ) {
+    stop(
+      "The `fmt_scientific()` function can only be used on `columns` with numeric data.",
+      call. = FALSE
+    )
   }
 
   # Pass `data`, `columns`, `rows`, and the formatting
@@ -346,16 +492,25 @@ fmt_scientific <- function(data,
         }
 
         # Create the `suffix_df` object
-        suffix_df <- create_suffix_df(x, decimals, suffix_labels, scale_by)
+        suffix_df <-
+          create_suffix_df(
+            x,
+            decimals = decimals,
+            suffix_labels = suffix_labels,
+            scale_by = scale_by
+          )
 
-        # Scale the `x_vals` by the `scale_by` values
-        x <- x %>% scale_x_values(suffix_df$scale_by)
+        # Scale the `x` values by the `scale_by` values in `suffix_df`
+        x <- scale_x_values(x, scale_by = suffix_df$scale_by)
 
         x_str <-
-          x %>%
           format_num_to_str(
-            context = context, decimals = decimals, n_sigfig = NULL,
-            sep_mark = sep_mark, dec_mark = dec_mark,
+            x,
+            context = context,
+            decimals = decimals,
+            n_sigfig = NULL,
+            sep_mark = sep_mark,
+            dec_mark = dec_mark,
             drop_trailing_zeros = drop_trailing_zeros,
             drop_trailing_dec_mark = FALSE,
             format = "e",
@@ -384,6 +539,193 @@ fmt_scientific <- function(data,
             exp_marks[2]
           )
 
+        # Force a positive sign on certain values if the option is taken
+        if (force_sign) {
+
+          positive_x <- !is.na(x) & x > 0
+          x_str[positive_x] <- paste_left(x_str[positive_x], x_left = "+")
+        }
+
+        x_str
+      }
+    )
+  )
+}
+
+#' Format values to engineering notation
+#'
+#' @description
+#' With numeric values in a **gt** table, we can perform formatting so that the
+#' targeted values are rendered in engineering notation.
+#'
+#' With this function, there is fine control over the formatted values with the
+#' following options:
+#'
+#' - decimals: choice of the number of decimal places, option to drop
+#' trailing zeros, and a choice of the decimal symbol
+#' - digit grouping separators: choice of separator symbol
+#' - scaling: we can choose to scale targeted values by a multiplier value
+#' - pattern: option to use a text pattern for decoration of the formatted
+#' values
+#' - locale-based formatting: providing a locale ID will result in
+#' formatting specific to the chosen locale
+#'
+#' @details
+#' Targeting of values is done through `columns` and additionally by `rows` (if
+#' nothing is provided for `rows` then entire columns are selected). A number of
+#' helper functions exist to make targeting more effective. Conditional
+#' formatting is possible by providing a conditional expression to the `rows`
+#' argument. See the Arguments section for more information on this.
+#'
+#' @inheritParams fmt_number
+#' @param scale_by A value to scale the input. The default is `1.0`. All numeric
+#'   values will be multiplied by this value first before undergoing formatting.
+#' @param force_sign Should the positive sign be shown for positive values
+#'   (effectively showing a sign for all values except zero)? If so, use `TRUE`
+#'   for this option. The default is `FALSE`, where only negative numbers will
+#'   display a minus sign.
+#'
+#' @return An object of class `gt_tbl`.
+#'
+#' @examples
+#' # Use `exibble` to create a gt table;
+#' # format the `num` column in
+#' # engineering notation
+#' tab_1 <-
+#'   exibble %>%
+#'   gt() %>%
+#'   fmt_engineering(columns = num)
+#'
+#' @section Figures:
+#' \if{html}{\figure{man_fmt_engineering_1.png}{options: width=100\%}}
+#'
+#' @family Format Data
+#' @section Function ID:
+#' 3-4
+#'
+#' @export
+fmt_engineering <- function(data,
+                            columns,
+                            rows = everything(),
+                            decimals = 2,
+                            drop_trailing_zeros = FALSE,
+                            scale_by = 1.0,
+                            pattern = "{x}",
+                            sep_mark = ",",
+                            dec_mark = ".",
+                            force_sign = FALSE,
+                            locale = NULL) {
+
+  # Perform input object validation
+  stop_if_not_gt(data = data)
+
+  # Set default values
+  suffixing <- FALSE
+  use_seps <- TRUE
+
+  # Use locale-based marks if a locale ID is provided
+  sep_mark <- get_locale_sep_mark(locale, sep_mark, use_seps)
+  dec_mark <- get_locale_dec_mark(locale, dec_mark)
+
+  # Stop function if `locale` does not have a valid value
+  validate_locale(locale = locale)
+
+  # Normalize the `suffixing` input to either return a character vector
+  # of suffix labels, or NULL (the case where `suffixing` is FALSE)
+  suffix_labels <- normalize_suffixing_inputs(suffixing, scale_by)
+
+  # Stop function if any columns have data that is incompatible
+  # with this formatter
+  if (!column_classes_are_valid(data, {{ columns }}, valid_classes = c("numeric", "integer"))) {
+    stop("The `fmt_scientific()` function can only be used on `columns` with numeric data",
+         call. = FALSE)
+  }
+
+  # Pass `data`, `columns`, `rows`, and the formatting
+  # functions as a function list to `fmt()`
+  fmt(
+    data = data,
+    columns = {{ columns }},
+    rows = {{ rows }},
+    fns = num_fmt_factory_multi(
+      pattern = pattern,
+      format_fn = function(x, context) {
+        # Define the marks by context
+        exp_marks <- context_exp_marks(context)
+        minus_mark <- context_minus_mark(context)
+
+        # Define the `replace_minus()` function
+        replace_minus <- function(x) {
+          x %>% tidy_gsub("-", minus_mark, fixed = TRUE)
+        }
+
+        # Create the `suffix_df` object
+        suffix_df <-
+          create_suffix_df(
+            x,
+            decimals = decimals,
+            suffix_labels = suffix_labels,
+            scale_by = scale_by
+          )
+
+        # Scale the `x_vals` by the `scale_by` values
+        x <- scale_x_values(x, suffix_df$scale_by)
+
+        zero_x <- x == 0
+        negative_x <- x < 0
+        x_str_left <- x_str_right <- x_str <- character(length = length(x))
+
+        # Powers in engineering notation always in steps of 3; this
+        # calculation gets, for every value, the effective power value
+        power_3 <- floor(log(abs(x), base = 1000)) * 3
+
+        # Any zero values will return Inf from the previous calculation
+        # so we must replace these with a `0`
+        power_3[is.infinite(power_3)] <- 0L
+
+        # The numbers on the LHS must be scaled to correspond to the
+        # RHS 10^`power_level` values (i.e., `<LHS> x 10^(n * 3)`)
+        x <- x / 10^(power_3)
+
+        # With the scaled values for the LHS, format these according
+        # to the options set by the user
+        x_str_left <-
+          format_num_to_str(
+            x,
+            context = context,
+            decimals = decimals,
+            n_sigfig = NULL,
+            sep_mark = sep_mark,
+            dec_mark = dec_mark,
+            drop_trailing_zeros = drop_trailing_zeros,
+            drop_trailing_dec_mark = FALSE,
+            format = "f",
+            replace_minus_mark = FALSE
+          ) %>%
+          replace_minus()
+
+        # Generate the RHS of the formatted value (i.e., the `x 10^(n * 3)`)
+        x_str_right <-
+          paste0(
+            exp_marks[1],
+            as.character(power_3) %>% replace_minus(),
+            exp_marks[2]
+          )
+
+        # Replace elements from `x_str_right` where exponent values
+        # are zero with empty strings
+        x_str_right[power_3 == 0] <- ""
+
+        # Paste the LHS and RHS components to generate the formatted values
+        x_str <- paste0(x_str_left, x_str_right)
+
+        # Force a positive sign on certain values if the option is taken
+        if (force_sign) {
+
+          positive_x <- !is.na(x) & x > 0
+          x_str[positive_x] <- paste_left(x_str[positive_x], x_left = "+")
+        }
+
         x_str
       }
     )
@@ -410,6 +752,7 @@ fmt_symbol <- function(data,
                        pattern = "{x}",
                        sep_mark = ",",
                        dec_mark = ".",
+                       force_sign = FALSE,
                        placement = "left",
                        incl_space = FALSE,
                        locale = NULL) {
@@ -419,7 +762,7 @@ fmt_symbol <- function(data,
   dec_mark <- get_locale_dec_mark(locale, dec_mark)
 
   # Stop function if `locale` does not have a valid value
-  validate_locale(locale)
+  validate_locale(locale = locale)
 
   # Normalize the `suffixing` input to either return a character vector
   # of suffix labels, or NULL (the case where `suffixing` is FALSE)
@@ -439,22 +782,31 @@ fmt_symbol <- function(data,
         x_str <- character(length(x))
 
         # Create the `suffix_df` object
-        suffix_df <- create_suffix_df(x, decimals, suffix_labels, scale_by)
+        suffix_df <-
+          create_suffix_df(
+            x,
+            decimals = decimals,
+            suffix_labels = suffix_labels,
+            scale_by = scale_by
+          )
 
         # Scale the `x_vals` by the `scale_by` value
-        x <- x %>% scale_x_values(suffix_df$scale_by)
+        x <- scale_x_values(x, suffix_df$scale_by)
 
         is_negative_x <- x < 0
         is_not_negative_x <- !is_negative_x
 
         if (any(is_not_negative_x)) {
 
+          # Format numeric values to character-based numbers
           x_str[is_not_negative_x] <-
-            x[is_not_negative_x] %>%
-            # Format numeric values to character-based numbers
             format_num_to_str_c(
-              context = context, decimals = decimals, sep_mark = sep_mark,
-              dec_mark = dec_mark, drop_trailing_zeros = drop_trailing_zeros,
+              x[is_not_negative_x],
+              context = context,
+              decimals = decimals,
+              sep_mark = sep_mark,
+              dec_mark = dec_mark,
+              drop_trailing_zeros = drop_trailing_zeros,
               drop_trailing_dec_mark = drop_trailing_dec_mark
             )
         }
@@ -463,31 +815,48 @@ fmt_symbol <- function(data,
 
         if (any(is_negative_x)) {
 
+          # Format numeric values to character-based numbers
           x_abs_str[is_negative_x] <-
-            x[is_negative_x] %>%
-            abs() %>%
-            # Format numeric values to character-based numbers
             format_num_to_str_c(
-              context = context, decimals = decimals, sep_mark = sep_mark,
-              dec_mark = dec_mark, drop_trailing_zeros = drop_trailing_zeros,
+              abs(x[is_negative_x]),
+              context = context,
+              decimals = decimals,
+              sep_mark = sep_mark,
+              dec_mark = dec_mark,
+              drop_trailing_zeros = drop_trailing_zeros,
               drop_trailing_dec_mark = drop_trailing_dec_mark
             )
         }
 
+        # Format values with a symbol string
         x_str <-
-          # Format values with a symbol string
           format_symbol_str(
-            context = context, x_abs_str = x_abs_str, x = x,
-            symbol = symbol, incl_space = incl_space,
+            x_abs_str = x_abs_str,
+            x = x,
+            context = context,
+            symbol = symbol,
+            incl_space = incl_space,
             placement = placement
-          ) %>%
-          # Format values in accounting style
+          )
+
+        # Format values in accounting notation (if `accounting = TRUE`)
+        x_str <-
           format_as_accounting(
-            x = x, context = context, accounting = accounting
-          ) %>%
-          # With large-number suffixing support, we paste the
-          # vector of suffixes to the right of the values
-          paste_right(suffix_df$suffix)
+            x_str,
+            x = x,
+            context = context,
+            accounting = accounting
+          )
+
+        # Paste the vector of suffixes to the right of the values
+        x_str <- paste_right(x_str, x_right = suffix_df$suffix)
+
+        # Force a positive sign on certain values if the option is taken
+        if (!accounting && force_sign) {
+
+          positive_x <- !is.na(x) & x > 0
+          x_str[positive_x] <- paste_left(x_str[positive_x], x_left = "+")
+        }
 
         x_str
       }
@@ -557,7 +926,7 @@ fmt_symbol <- function(data,
 #'
 #' @family Format Data
 #' @section Function ID:
-#' 3-3
+#' 3-5
 #'
 #' @import rlang
 #' @export
@@ -573,6 +942,7 @@ fmt_percent <- function(data,
                         pattern = "{x}",
                         sep_mark = ",",
                         dec_mark = ".",
+                        force_sign = FALSE,
                         incl_space = FALSE,
                         placement = "right",
                         locale = NULL) {
@@ -582,9 +952,17 @@ fmt_percent <- function(data,
 
   # Stop function if any columns have data that is incompatible
   # with this formatter
-  if (!column_classes_are_valid(data, {{ columns }}, valid_classes = c("numeric", "integer"))) {
-    stop("The `fmt_percent()` function can only be used on `columns` with numeric data",
-         call. = FALSE)
+  if (
+    !column_classes_are_valid(
+      data = data,
+      columns = {{ columns }},
+      valid_classes = c("numeric", "integer")
+    )
+  ) {
+    stop(
+      "The `fmt_percent()` function can only be used on `columns` with numeric data.",
+      call. = FALSE
+    )
   }
 
   if (scale_values) {
@@ -593,6 +971,7 @@ fmt_percent <- function(data,
     scale_by <- 1.0
   }
 
+  # Pass `data`, `columns`, `rows`, and other options to `fmt_symbol()`
   fmt_symbol(
     data = data,
     columns = {{ columns }},
@@ -608,6 +987,7 @@ fmt_percent <- function(data,
     pattern = pattern,
     sep_mark = sep_mark,
     dec_mark = dec_mark,
+    force_sign = force_sign,
     placement = placement,
     incl_space = incl_space,
     locale = locale
@@ -719,7 +1099,7 @@ fmt_percent <- function(data,
 #'
 #' @family Format Data
 #' @section Function ID:
-#' 3-4
+#' 3-6
 #'
 #' @import rlang
 #' @export
@@ -737,6 +1117,7 @@ fmt_currency <- function(data,
                          pattern = "{x}",
                          sep_mark = ",",
                          dec_mark = ".",
+                         force_sign = FALSE,
                          placement = "left",
                          incl_space = FALSE,
                          locale = NULL) {
@@ -746,9 +1127,17 @@ fmt_currency <- function(data,
 
   # Stop function if any columns have data that is incompatible
   # with this formatter
-  if (!column_classes_are_valid(data, {{ columns }}, valid_classes = c("numeric", "integer"))) {
-    stop("The `fmt_currency()` function can only be used on `columns` with numeric data",
-         call. = FALSE)
+  if (
+    !column_classes_are_valid(
+      data = data,
+      columns = {{ columns }},
+      valid_classes = c("numeric", "integer")
+    )
+  ) {
+    stop(
+      "The `fmt_currency()` function can only be used on `columns` with numeric data.",
+      call. = FALSE
+    )
   }
 
   # Stop function if `currency` does not have a valid value
@@ -762,6 +1151,7 @@ fmt_currency <- function(data,
       use_subunits = use_subunits
     )
 
+  # Pass `data`, `columns`, `rows`, and other options to `fmt_symbol()`
   fmt_symbol(
     data = data,
     columns = {{ columns }},
@@ -777,6 +1167,7 @@ fmt_currency <- function(data,
     pattern = pattern,
     sep_mark = sep_mark,
     dec_mark = dec_mark,
+    force_sign = force_sign,
     placement = placement,
     incl_space = incl_space,
     locale = locale
@@ -819,6 +1210,10 @@ fmt_currency <- function(data,
 #'   use. The default number of decimal places is `1`.
 #' @param incl_space An option for whether to include a space between the value
 #'   and the units. The default of `TRUE` uses a space character for separation.
+#' @param force_sign Should the positive sign be shown for positive numbers
+#'   (effectively showing a sign for all numbers except zero)? If so, use `TRUE`
+#'   for this option. The default is `FALSE`, where only negative numbers will
+#'   display a minus sign.
 #'
 #' @return An object of class `gt_tbl`.
 #'
@@ -846,7 +1241,7 @@ fmt_currency <- function(data,
 #'
 #' @family Format Data
 #' @section Function ID:
-#' 3-5
+#' 3-7
 #'
 #' @import rlang
 #' @export
@@ -862,6 +1257,7 @@ fmt_bytes <- function(data,
                       pattern = "{x}",
                       sep_mark = ",",
                       dec_mark = ".",
+                      force_sign = FALSE,
                       incl_space = TRUE,
                       locale = NULL) {
 
@@ -879,23 +1275,27 @@ fmt_bytes <- function(data,
   if (!is.null(n_sigfig)) {
 
     # Stop function if `n_sigfig` does not have a valid value
-    validate_n_sigfig(n_sigfig)
+    validate_n_sigfig(n_sigfig = n_sigfig)
 
     formatC_format <- "fg"
+
   } else {
     formatC_format <- "f"
   }
 
   if (standard == "decimal") {
+
     base <- 1000
-    byte_units <-
-      c("B", "kB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB")
+    byte_units <- c("B", "kB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB")
+
   } else {
+
     base <- 1024
-    byte_units <-
-      c("B", "KiB", "MiB", "GiB", "TiB", "PiB", "EiB", "ZiB", "YiB")
+    byte_units <- c("B", "KiB", "MiB", "GiB", "TiB", "PiB", "EiB", "ZiB", "YiB")
   }
 
+  # Pass `data`, `columns`, `rows`, and the formatting
+  # functions as a function list to `fmt()`
   fmt(
     data = data,
     columns = {{ columns }},
@@ -913,16 +1313,29 @@ fmt_bytes <- function(data,
         units_str <- byte_units[num_power_idx]
         x <- x / base^(num_power_idx-1)
 
-        x %>%
-          # Format numeric values to character-based numbers
+        # Format numeric values to character-based numbers
+        x_str <-
           format_num_to_str(
-            context = context, decimals = decimals, n_sigfig = n_sigfig,
-            sep_mark = sep_mark, dec_mark = dec_mark,
+            x,
+            context = context,
+            decimals = decimals,
+            n_sigfig = n_sigfig,
+            sep_mark = sep_mark,
+            dec_mark = dec_mark,
             drop_trailing_zeros = drop_trailing_zeros,
             drop_trailing_dec_mark = drop_trailing_dec_mark,
             format = formatC_format
           ) %>%
-          paste_right(paste0(if (incl_space) " ", units_str))
+          paste_right(x_right = paste0(if (incl_space) " ", units_str))
+
+        # Force a positive sign on certain values if the option is taken
+        if (force_sign) {
+
+          positive_x <- !is.na(x) & x > 0
+          x_str[positive_x] <- paste_left(x_str[positive_x], x_left = "+")
+        }
+
+        x_str
       }
     )
   )
@@ -1015,7 +1428,7 @@ fmt_bytes <- function(data,
 #'
 #' @family Format Data
 #' @section Function ID:
-#' 3-6
+#' 3-8
 #'
 #' @import rlang
 #' @export
@@ -1032,9 +1445,17 @@ fmt_date <- function(data,
 
   # Stop function if any columns have data that is incompatible
   # with this formatter
-  if (!column_classes_are_valid(data, {{ columns }}, valid_classes = c("Date", "character"))) {
-    stop("The `fmt_date()` function can only be used on `columns` with `character` or `Date` values",
-         call. = FALSE)
+  if (
+    !column_classes_are_valid(
+      data = data,
+      columns = {{ columns }},
+      valid_classes = c("Date", "character")
+    )
+  ) {
+    stop(
+      "The `fmt_date()` function can only be used on `columns` with `character` or `Date` values.",
+      call. = FALSE
+    )
   }
 
   # Pass `data`, `columns`, `rows`, and the formatting
@@ -1146,7 +1567,7 @@ fmt_date <- function(data,
 #'
 #' @family Format Data
 #' @section Function ID:
-#' 3-7
+#' 3-9
 #'
 #' @import rlang
 #' @export
@@ -1163,9 +1584,16 @@ fmt_time <- function(data,
 
   # Stop function if any columns have data that is incompatible
   # with this formatter
-  if (!column_classes_are_valid(data, {{ columns }}, valid_classes = "character")) {
-    stop("The `fmt_date()` function can only be used on `columns` with `character` values",
-         call. = FALSE)
+  if (
+    !column_classes_are_valid(
+      data = data,
+      columns = {{ columns }},
+      valid_classes = "character")
+  ) {
+    stop(
+      "The `fmt_date()` function can only be used on `columns` with `character` values.",
+      call. = FALSE
+    )
   }
 
   # Pass `data`, `columns`, `rows`, and the formatting
@@ -1266,7 +1694,7 @@ fmt_time <- function(data,
 #'
 #' @family Format Data
 #' @section Function ID:
-#' 3-8
+#' 3-10
 #'
 #' @import rlang
 #' @export
@@ -1287,9 +1715,16 @@ fmt_datetime <- function(data,
 
   # Stop function if any columns have data that is incompatible
   # with this formatter
-  if (!column_classes_are_valid(data, {{ columns }}, valid_classes = "character")) {
-    stop("The `fmt_datetime()` function can only be used on `columns` with `character` values",
-         call. = FALSE)
+  if (
+    !column_classes_are_valid(
+      data = data,
+      columns = {{ columns }},
+      valid_classes = "character"
+    )) {
+    stop(
+      "The `fmt_datetime()` function can only be used on `columns` with `character` values.",
+      call. = FALSE
+    )
   }
 
   # Pass `data`, `columns`, `rows`, and the formatting
@@ -1407,7 +1842,7 @@ fmt_datetime <- function(data,
 #'
 #' @family Format Data
 #' @section Function ID:
-#' 3-9
+#' 3-11
 #'
 #' @import rlang
 #' @export
@@ -1494,7 +1929,7 @@ fmt_markdown <- function(data,
 #'
 #' @family Format Data
 #' @section Function ID:
-#' 3-10
+#' 3-12
 #'
 #' @import rlang
 #' @export
@@ -1628,7 +2063,7 @@ fmt_passthrough <- function(data,
 #'
 #' @family Format Data
 #' @section Function ID:
-#' 3-11
+#' 3-13
 #'
 #' @import rlang
 #' @export
@@ -1663,6 +2098,7 @@ fmt_missing <- function(data,
         ifelse(is.na(x), missing_text, NA_character_)
       },
       rtf = function(x) {
+
         missing_text <-
           context_missing_text(
             missing_text = missing_text,
@@ -1697,6 +2133,7 @@ fmt_missing <- function(data,
 #' **gt**. Along with the `columns` and `rows` arguments that provide some
 #' precision in targeting data cells, the `fns` argument allows you to define
 #' one or more functions for manipulating the raw data.
+#'
 #' If providing a single function to `fns`, the recommended format is in the
 #' form: `fns = function(x) ...`. This single function will format the targeted
 #' data cells the same way regardless of the output format (e.g., HTML, LaTeX,
@@ -1742,7 +2179,7 @@ fmt_missing <- function(data,
 #'
 #' @family Format Data
 #' @section Function ID:
-#' 3-12
+#' 3-14
 #'
 #' @import rlang
 #' @export
