@@ -1,6 +1,3 @@
-
-grand_summary_col <- "::GRAND_SUMMARY"
-
 # Define the contexts
 all_contexts <- c("html", "latex", "rtf", "default")
 
@@ -246,22 +243,21 @@ reorder_styles <- function(data) {
   stub_df <- dt_stub_df_get(data = data)
   styles_tbl <- dt_styles_get(data = data)
 
-  rownum_final <-
-    stub_df %>%
-    dplyr::pull(rownum_i) %>%
-    as.numeric()
+  rownum_final <- as.numeric(stub_df[, "rownum_i", drop = TRUE])
 
   for (i in seq_len(nrow(styles_tbl))) {
-    if (!is.na(styles_tbl[i, ][["rownum"]])) {
+
+    if (
+      !is.na(styles_tbl[i, ][["rownum"]]) &&
+      !grepl("summary_cells", styles_tbl[i, ][["locname"]])
+    ) {
 
       styles_tbl[i, ][["rownum"]] <-
         which(rownum_final == styles_tbl[i, ][["rownum"]])
     }
   }
 
-  data <- dt_styles_set(data = data, styles = styles_tbl)
-
-  data
+  dt_styles_set(data = data, styles = styles_tbl)
 }
 
 #' Perform merging of column contents
@@ -386,136 +382,6 @@ perform_col_merge <- function(data,
   data
 }
 
-# Function to build a vector of `group` rows in the table body
-create_group_rows <- function(n_rows,
-                              groups_rows_df,
-                              context = "latex") {
-
-  unname(
-    unlist(
-      lapply(
-        seq(n_rows),
-        FUN = function(x) {
-
-          if (!(x %in% groups_rows_df$row_start)) {
-            return("")
-          }
-
-          if (context == "latex") {
-
-            latex_group_row(
-              group_name = groups_rows_df[
-                which(groups_rows_df$row_start %in% x), "group_label"][[1]],
-              top_border = x != 1,
-              bottom_border = x != n_rows
-            )
-          }
-        })
-    )
-  )
-}
-
-# Function to build a vector of `data` rows in the table body
-create_data_rows <- function(n_rows,
-                             row_splits,
-                             context = "latex") {
-
-  unname(
-    unlist(
-      lapply(
-        seq(n_rows),
-        FUN = function(x) {
-          if (context == "latex") {
-            latex_body_row(content = row_splits[[x]], type = "row")
-          }
-        })
-    )
-  )
-}
-
-#' Split the body content vector into a list structure
-#'
-#' Taking the `body_content` vector, split into list components with one item
-#' per row in the output table
-#' @noRd
-split_body_content <- function(body_content,
-                               n_cols) {
-
-  if (length(body_content) == 0) {
-    return(list(rep("", n_cols)))
-  }
-
-  split(body_content, ceiling(seq_along(body_content) / n_cols))
-}
-
-# Function to build a vector of `summary` rows in the table body
-create_summary_rows <- function(n_rows,
-                                n_cols,
-                                list_of_summaries,
-                                groups_rows_df,
-                                stub_available,
-                                summaries_present,
-                                context = "latex") {
-
-  lapply(
-    seq(n_rows),
-    FUN = function(x) {
-
-      if (!stub_available ||
-          !summaries_present ||
-          !(x %in% groups_rows_df$row_end)) {
-        return("")
-      }
-
-      group <-
-        groups_rows_df %>%
-        dplyr::filter(row_end == x) %>%
-        dplyr::pull(group_id)
-
-      if (!(group %in% names(list_of_summaries$summary_df_display_list))) {
-        return("")
-      }
-
-      summary_df <-
-        list_of_summaries$summary_df_display_list[[group]] %>%
-        dplyr::select(-groups) %>%
-        as.data.frame(stringsAsFactors = FALSE)
-
-      body_content_summary <- as.vector(t(summary_df))
-      row_splits_summary <-
-        split_body_content(
-          body_content = body_content_summary,
-          n_cols = n_cols
-        )
-
-      if (length(row_splits_summary) > 0) {
-
-        if (context == "latex") {
-
-          top_line <- "\\midrule \n"
-
-          s_rows <-
-            paste(
-              vapply(
-                row_splits_summary,
-                FUN.VALUE = character(1),
-                latex_body_row,
-                type = "row"
-              ),
-              collapse = ""
-            )
-
-          s_rows <- paste0(top_line, s_rows)
-        }
-
-      } else {
-        s_rows <- ""
-      }
-    }) %>%
-    unlist() %>%
-    unname()
-}
-
 #' Suitably replace `NA` values in the `groups_df` data frame
 #'
 #' @param groups_df The `groups_df` data frame.
