@@ -8,7 +8,7 @@ test_that("the `cols_move()` function works correctly", {
   # Create a `tbl_latex` object with `gt()`; the `mpg`,
   # `cyl`, and `drat` columns placed after `drat`
   tbl_latex <-
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
     cols_move(columns = c(mpg, cyl, disp), after = drat)
 
   # Expect a characteristic pattern
@@ -22,7 +22,7 @@ test_that("the `cols_move()` function works correctly", {
   # Create a `tbl_latex` object with `gt()`; the `mpg`,
   # `cyl`, and `drat` columns placed after `drat` using vectors
   tbl_latex <-
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
     cols_move(columns = c("mpg", "cyl", "disp"), after = c("drat"))
 
   # Expect a characteristic pattern
@@ -36,7 +36,7 @@ test_that("the `cols_move()` function works correctly", {
   # Create a `tbl_latex` object with `gt()`; the `mpg`,
   # `cyl`, and `drat` columns placed after `carb` (the end of the series)
   tbl_latex <-
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
     cols_move(columns = c(mpg, cyl, disp), after = carb)
 
   # Expect a characteristic pattern
@@ -53,7 +53,7 @@ test_that("the `cols_move_to_start()` function works correctly", {
   # Create a `tbl_latex` object with `gt()`; the `gear`,
   # and `carb` columns placed at the start
   tbl_latex <-
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
     cols_move_to_start(columns = c(gear, carb))
 
   # Expect a characteristic pattern
@@ -67,7 +67,7 @@ test_that("the `cols_move_to_start()` function works correctly", {
   # Create a `tbl_latex` object with `gt()`; the `gear`,
   # and `carb` columns placed at the start using vectors
   tbl_latex <-
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
     cols_move_to_start(columns = c("gear", "carb"))
 
   # Expect a characteristic pattern
@@ -84,7 +84,7 @@ test_that("the `cols_move_to_end()` function works correctly", {
   # Create a `tbl_latex` object with `gt()`; the `gear`,
   # and `carb` columns placed at the end
   tbl_latex <-
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
     cols_move_to_end(columns = c(gear, carb))
 
   # Expect a characteristic pattern
@@ -98,7 +98,7 @@ test_that("the `cols_move_to_end()` function works correctly", {
   # Create a `tbl_latex` object with `gt()`; the `gear`,
   # and `carb` columns placed at the end using vectors
   tbl_latex <-
-    gt(data = mtcars_short) %>%
+    gt(mtcars_short) %>%
     cols_move_to_end(columns = c("gear", "carb"))
 
   # Expect a characteristic pattern
